@@ -1,18 +1,22 @@
 from .curio import *
 from .framing import *
 from .jsonrpc import *
+from .rawsocket import *
 from .socks import *
 from .session import *
 from .util import *
+from .websocket import *
 
 
-_version_str = '0.17.0'
+_version_str = '0.18.0'
 _version = tuple(int(part) for part in _version_str.split('.'))
 
 
 __all__ = (curio.__all__ +
            framing.__all__ +
            jsonrpc.__all__ +
+           rawsocket.__all__ +
            socks.__all__ +
            session.__all__ +
-           util.__all__)
+           util.__all__ +
+           websocket.__all__)
